@@ -27,8 +27,9 @@
 #' @export
 pack_randomized <- function(raster) {
 
-  # wrap observerd raster
-  raster$observed <- terra::wrap(raster$observed)
+  # check if observed is present
+  # wrap observed raster
+  if (inherits(x = raster$observed, what = "SpatRaster")) raster$observed <- terra::wrap(raster$observed)
 
   # wrap all randomized raster
   raster$randomized <- lapply(X = raster$randomized, FUN = terra::wrap)
