@@ -13,16 +13,13 @@
 #' stop if the energy does not decrease.
 #' @param annealing Double with probability to keep relocated point even if energy
 #' did not decrease.
-#' @param comp_fast Integer with threshold at which summary functions are estimated
-#' in a computational fast way.
-#' @param n_points Integer with number of points to be simulated.
-#' @param window owin object with window of simulated pattern.
 #' @param weights Vector with weights used to calculate energy.
 #' The first number refers to Gest(r), the second number to pcf(r).
 #' @param r_length Integer with number of intervals from \code{r=0} to \code{r=rmax} for which
 #' the summary functions are evaluated.
 #' @param r_max Double with maximum distance used during calculation of summary functions. If \code{NULL},
 #' will be estimated from data.
+#' @param stoyan Coefficient for Stoyan's bandwidth selection rule.
 #' @param return_input Logical if the original input data is returned.
 #' @param simplify Logical if only pattern will be returned if \code{n_random=1}
 #' and \code{return_input=FALSE}.
@@ -37,16 +34,12 @@
 #' The pair correlation function and the nearest neighbour distance function are
 #' used to describe the patterns.
 #'
-#' For large patterns (\code{n > comp_fast}) the pair correlation function can be estimated
-#' from Ripley's K-function without edge correction. This decreases the computational
-#' time. For more information see \code{\link{estimate_pcf_fast}}.
-#'
 #' The reconstruction can be stopped automatically if for n steps the energy does not
 #' decrease. The number of steps can be controlled by \code{no_change} and is set to
 #' \code{no_change = Inf} as default to never stop automatically.
 #'
 #' The weights must be 0 < sum(weights) <= 1. To weight both summary functions identical,
-#' use \code{weights = c(0.5, 0.5)}.
+#' use \code{weights = c(1, 1)}.
 #'
 #' \code{spatstat} sets \code{r_length} to 513 by default. However, a lower value decreases
 #' the computational time, while increasing the "bumpiness" of the summary function.
@@ -94,71 +87,65 @@
 reconstruct_pattern <- function(pattern, method = "homo",
                                 n_random = 1,
                                 e_threshold = 0.01,
-                                max_runs = 1000,
+                                max_runs,
                                 no_change = Inf,
                                 annealing = 0.01,
-                                comp_fast = 1000,
-                                n_points = NULL,
-                                window = NULL,
-                                weights = c(0.5, 0.5),
-                                r_length = 250,
+                                weights = c(1, 1),
+                                r_length = 255,
                                 r_max = NULL,
+                                stoyan = 0.15,
                                 return_input = TRUE,
                                 simplify = FALSE,
                                 verbose = TRUE,
                                 plot = FALSE) {
 
-  if (method == "homo") {
+  # check if correct method is selected
+  if (!method %in% c("homo", "hetero", "cluster")) stop("Method must be one of the following: 'homo', 'hetero', or 'cluster'.",
+                                                        call. = FALSE)
 
-    reconstruction <- reconstruct_pattern_homo(pattern = pattern, n_random = n_random,
-                                               e_threshold = e_threshold, max_runs = max_runs,
-                                               no_change = no_change, annealing = annealing,
-                                               comp_fast = comp_fast, n_points = n_points,
-                                               window = window, weights = weights,
-                                               r_length = r_length, r_max = r_max, return_input = return_input,
-                                               simplify = simplify, verbose = verbose,
-                                               plot = plot)
+  reconstruction <- reconstruct_algorithm(pattern = pattern, method = method, n_random = n_random,
+                                          e_threshold = e_threshold, max_runs = max_runs,
+                                          no_change = no_change, annealing = annealing,
+                                          weights = weights, r_length = r_length, r_max = r_max,
+                                          stoyan = stoyan, verbose = verbose, plot = plot)
 
+  # set class of result
+  class(reconstruction) <- "rd_pat"
 
+  # remove input if return_input = FALSE
+  if (!return_input) {
 
-  } else if (method == "cluster") {
+    # set observed to NA
+    reconstruction$observed <- "NA"
 
-    if (verbose && (!is.null(n_points) || !is.null(window) || !is.null(r_max))) {
+    # check if output should be simplified
+    if (simplify) {
 
-      warning("'n_points', 'window', or 'r_max' are not used for method='cluster'.", call. = FALSE)
+      # not possible if more than one pattern is present
+      if (n_random > 1 && verbose) {
 
+        warning("'simplify = TRUE' not possible for 'n_random > 1'.",
+                call. = FALSE)
+
+        # only one random pattern is present that should be returend
+      } else if (n_random == 1) {
+
+        reconstruction <- reconstruction$randomized[[1]]
+
+      }
     }
 
-    reconstruction <- reconstruct_pattern_cluster(pattern = pattern, n_random = n_random,
-                                                  e_threshold = e_threshold, max_runs = max_runs,
-                                                  no_change = no_change, annealing = annealing,
-                                                  comp_fast = comp_fast, weights = weights,
-                                                  r_length = r_length, r_max = r_max, return_input = return_input,
-                                                  simplify = simplify, verbose = verbose,
-                                                  plot = plot)
-
-  } else if (method == "hetero") {
-
-    if (verbose && (!is.null(n_points) || !is.null(window) || !is.null(r_max))) {
-
-      warning("'n_points', 'window', or 'r_max' are not used for method='hetero'.", call. = FALSE)
-
-    }
-
-    reconstruction <- reconstruct_pattern_hetero(pattern = pattern, n_random = n_random,
-                                                 e_threshold = e_threshold, max_runs = max_runs,
-                                                 no_change = no_change, annealing = annealing,
-                                                 comp_fast = comp_fast, weights = weights,
-                                                 r_length = r_length, r_max = r_max, return_input = return_input,
-                                                 simplify = simplify, verbose = verbose,
-                                                 plot = plot)
-
+    # return input if return_input = TRUE
   } else {
 
-    stop("Method must be one of the following: 'homo', 'cluster', 'hetero', or 'marks'.",
-         call. = FALSE)
+    # return warning if simply = TRUE because not possible if return_input = TRUE (only verbose = TRUE)
+    if (simplify && verbose) {
 
+      warning("'simplify = TRUE' not possible for 'return_input = TRUE'.", call. = FALSE)
+
+    }
   }
 
   return(reconstruction)
+
 }
