@@ -10,9 +10,8 @@ marks_sub <- spatstat.geom::subset.ppp(species_a, select = dbh)
 marks_recon <- reconstruct_pattern_marks(pattern_random_a$randomized[[1]], marks_sub,
                                          n_random = 3, max_runs = 10, verbose = FALSE)
 
-marks_recon_NA  <- marks_recon
-
-marks_recon_NA$energy_df <- "NA"
+marks_recon_na <- marks_recon
+marks_recon_na$energy_df <- "NA"
 
 ################################################################################
 
@@ -31,7 +30,6 @@ testthat::test_that("calculate_energy uses weights", {
   testthat::expect_false(unweighted == weighted)
 })
 
-
 testthat::test_that("calculate_energy returns mean ", {
 
   mean_energy <- mean(calculate_energy(pattern_random_a, verbose = FALSE))
@@ -41,13 +39,6 @@ testthat::test_that("calculate_energy returns mean ", {
                          expected = mean_energy)
 })
 
-testthat::test_that("calculate_energy can use comp_fast ", {
-
-  testthat::expect_length(calculate_energy(pattern_random_a, comp_fast = 50,
-                                           verbose = FALSE),
-                          n = 3)
-})
-
 testthat::test_that("calculate_energy returns works for reconstructed marks", {
 
   testthat::expect_length(calculate_energy(marks_recon, verbose = FALSE), n = 3)
@@ -57,8 +48,8 @@ testthat::test_that("calculate_energy returns works for reconstructed marks", {
   testthat::expect_equal(calculate_energy(marks_recon, return_mean = TRUE,
                                           verbose = FALSE), expected = mean_energy)
 
-  testthat::expect_equal(calculate_energy(marks_recon_NA, return_mean = TRUE,
-                                          verbose = FALSE), expected = mean_energy)
+  testthat::expect_length(calculate_energy(marks_recon_na, verbose = FALSE), n = 3)
+
   })
 
 testthat::test_that("calculate_energy returns error if observed not included", {
@@ -74,17 +65,3 @@ testthat::test_that("calculate_energy returns error if wrong class ", {
                          regexp = "Class of 'pattern' must be 'rd_pat' or 'rd_mar'.",
                          fixed = TRUE)
 })
-
-testthat::test_that("calculate_energy returns error if weights are wrong ", {
-
-  testthat::expect_error(calculate_energy(pattern_random_a, weights = c(0, 0),
-                                          return_mean = TRUE, verbose = FALSE),
-                         regexp = "The sum of 'weights' must be 0 < sum(weights) <= 1.",
-                         fixed = TRUE)
-
-  testthat::expect_error(calculate_energy(pattern_random_a, weights = c(1, 1),
-                                          return_mean = TRUE, verbose = FALSE),
-                         regexp = "The sum of 'weights' must be 0 < sum(weights) <= 1.",
-                         fixed = TRUE)
-})
-
